Welcome to pyrcv's documentation!
=================================

Python project for adjudicating ranked choice voting elections using the
single transferable vote (STV) method.  For more information on ranked
choice voting, visit the `FairVote website on RCV`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _FairVote website on RCV: https://fairvote.org/our-reforms/ranked-choice-voting/
